@@ -1,6 +1,8 @@
 package DTL::Fast::Tag::Verbatim;
 use strict; use utf8; use warnings FATAL => 'all'; 
 use parent 'DTL::Fast::Tag';  
+use Carp qw(confess);
+
 $DTL::Fast::TAG_HANDLERS{'verbatim'} = __PACKAGE__;
 
 use DTL::Fast::Text;
@@ -14,8 +16,8 @@ sub parse_parameters
     my $self = shift;
     $self->{'contents'} = DTL::Fast::Text->new();
     $self->{'last_tag'} = $self->{'parameter'} ?
-        qr/\Qendverbatim\E\s+\Q$self->{'parameter'}\E/
-        : 'endverbatim';
+        sprintf( '{%% %s %s %%}', $self->get_close_tag, $self->{'parameter'})
+        : '{% endverbatim %}';
     return $self;
 }
 
@@ -25,7 +27,7 @@ sub parse_next_chunk
     my $self = shift;
     my $chunk = shift @{$self->{'raw_chunks'}};
     
-    if( $chunk =~ /^\{\%\s*$self->{'last_tag'}\s*\%\}$/six )
+    if( $chunk eq $self->{'last_tag'} )
     {
         $self->{'raw_chunks'} = []; # this stops parsing
     }
